@@ -279,17 +279,19 @@ not found, the original unmodified tree will be returned."
 "Calls proc for each of the key-value pairs in tree, moving from
 smallest to greatest key. proc must take an argument of the form (key
 . value). Does not return results."
-  (if (left-tree tree) (aa-for-each proc (left-tree tree)))
-  (proc (key-value tree))
-  (if (right-tree tree) (aa-for-each proc (right-tree tree))))
+  (unless (nil? tree)
+    (if (left-tree tree) (aa-for-each proc (left-tree tree)))
+    (proc (key-value tree))
+    (if (right-tree tree) (aa-for-each proc (right-tree tree)))))
 
 (define (aa-for-each-reverse proc tree)
 "Calls proc for each of the key-value pairs in tree, moving from
 smallest to greatest key. proc must take an argument of the form (key
 . value). Does not return results."
-  (if (right-tree tree) (aa-for-each-reverse proc (right-tree tree)))
-  (proc (key-value tree))
-  (if (left-tree tree) (aa-for-each-reverse proc (left-tree tree))))
+  (unless (nil? tree)
+    (if (right-tree tree) (aa-for-each-reverse proc (right-tree tree)))
+    (proc (key-value tree))
+    (if (left-tree tree) (aa-for-each-reverse proc (left-tree tree)))))
 
 (define (aa-map fn tree)
   "Maps fn over the key-value pairs in tree, ordered from smallest to
